@@ -1,4 +1,4 @@
-#' Probabilties of assignment: Blocked and Clustered Random Assignment
+#' probabilities of assignment: Blocked and Clustered Random Assignment
 #'
 #' @inheritParams block_and_cluster_ra
 #'
@@ -53,7 +53,7 @@ block_and_cluster_ra_probabilities <-
            block_prob = NULL,
            block_prob_each = NULL,
            num_arms = NULL,
-           condition_names = NULL,
+           conditions = NULL,
            check_inputs = TRUE,
            block_var = NULL,
            clust_var = NULL) {
@@ -74,7 +74,7 @@ block_and_cluster_ra_probabilities <-
           block_prob = block_prob,
           block_prob_each = block_prob_each,
           num_arms = num_arms,
-          condition_names = condition_names
+          conditions = conditions
         )
     }
     
@@ -95,7 +95,7 @@ block_and_cluster_ra_probabilities <-
       block_prob = block_prob,
       block_prob_each = block_prob_each,
       num_arms = num_arms,
-      condition_names = condition_names,
+      conditions = conditions,
       check_inputs = check_inputs
     )
     
