@@ -6,18 +6,19 @@
 #' @param m Use for a two-arm design in which m units (or clusters) are assigned to treatment and N-m units (or clusters) are assigned to control. In a blocked design, exactly m units in each block will be treated. (optional)
 #' @param m_each Use for a multi-arm design in which the values of m_each determine the number of units (or clusters) assigned to each condition. m_each must be a numeric vector in which each entry is a nonnegative integer that describes how many units (or clusters) should be assigned to the 1st, 2nd, 3rd... treatment condition. m_each must sum to N. (optional)
 #' @param prob Use for a two-arm design in which either floor(N*prob) or ceiling(N*prob) units (or clusters) are assigned to treatment. The probability of assignment to treatment is exactly prob because with probability 1-prob, floor(N*prob) units (or clusters) will be assigned to treatment and with probability prob, ceiling(N*prob) units (or clusters) will be assigned to treatment. prob must be a real number between 0 and 1 inclusive. (optional)
-#' @param prob_each Use for a multi-arm design in which the values of prob_each determine the probabilties of assignment to each treatment condition. prob_each must be a numeric vector giving the probability of assignment to each condition. All entries must be nonnegative real numbers between 0 and 1 inclusive and the total must sum to 1. Because of integer issues, the exact number of units assigned to each condition may differ (slightly) from assignment to assignment, but the overall probability of assignment is exactly prob_each. (optional)
+#' @param prob_each Use for a multi-arm design in which the values of prob_each determine the probabilities of assignment to each treatment condition. prob_each must be a numeric vector giving the probability of assignment to each condition. All entries must be nonnegative real numbers between 0 and 1 inclusive and the total must sum to 1. Because of integer issues, the exact number of units assigned to each condition may differ (slightly) from assignment to assignment, but the overall probability of assignment is exactly prob_each. (optional)
 #' @param block_m Use for a two-arm design in which block_m describes the number of units to assign to treatment within each block. Note that in previous versions of randomizr, block_m behaved like block_m_each.
-#' @param block_m_each Use for a multi-arm design in which the values of block_m_each determine the number of units (or clusters) assigned to each condition. block_m_each must be a matrix with the same number of rows as blocks and the same number of columns as treatment arms. Cell entries are the number of units (or clusters) to be assigned to each treatment arm within each block. The rows should respect the ordering of the blocks as determined by sort(unique(blocks)). The columns should be in the order of condition_names, if specified.
+#' @param block_m_each Use for a multi-arm design in which the values of block_m_each determine the number of units (or clusters) assigned to each condition. block_m_each must be a matrix with the same number of rows as blocks and the same number of columns as treatment arms. Cell entries are the number of units (or clusters) to be assigned to each treatment arm within each block. The rows should respect the ordering of the blocks as determined by sort(unique(blocks)). The columns should be in the order of conditions, if specified.
 #' @param block_prob Use for a two-arm design in which block_prob describes the probability of assignment to treatment within each block. Differs from prob in that the probability of assignment can vary across blocks.
-#' @param block_prob_each Use for a multi-arm design in which the values of block_prob_each determine the probabilties of assignment to each treatment condition. block_prob_each must be a matrix with the same number of rows as blocks and the same number of columns as treatment arms. Cell entries are the probabilites of assignment to treatment within each block. The rows should respect the ordering of the blocks as determined by sort(unique(blocks)). Use only if the probabilities of assignment should vary by block, otherwise use prob_each. Each row of block_prob_each must sum to 1.
+#' @param block_prob_each Use for a multi-arm design in which the values of block_prob_each determine the probabilities of assignment to each treatment condition. block_prob_each must be a matrix with the same number of rows as blocks and the same number of columns as treatment arms. Cell entries are the probabilities of assignment to treatment within each block. The rows should respect the ordering of the blocks as determined by sort(unique(blocks)). Use only if the probabilities of assignment should vary by block, otherwise use prob_each. Each row of block_prob_each must sum to 1.
 #' @param num_arms The number of treatment arms. If unspecified, num_arms will be determined from the other arguments. (optional)
-#' @param condition_names A character vector giving the names of the treatment groups. If unspecified, the treatment groups will be named 0 (for control) and 1 (for treatment) in a two-arm trial and T1, T2, T3, in a multi-arm trial. An execption is a two-group design in which num_arms is set to 2, in which case the condition names are T1 and T2, as in a multi-arm trial with two arms. (optional)
+#' @param conditions A character vector giving the names of the treatment groups. If unspecified, the treatment groups will be named 0 (for control) and 1 (for treatment) in a two-arm trial and T1, T2, T3, in a multi-arm trial. An exception is a two-group design in which num_arms is set to 2, in which case the condition names are T1 and T2, as in a multi-arm trial with two arms. (optional)
 #' @param simple logical, defaults to FALSE. If TRUE, simple random assignment is used. When simple = TRUE, please do not specify m, m_each, block_m, or block_m_each.
 #' @param permutation_matrix for custom random assignment procedures.
 #' @param check_inputs logical. Defaults to TRUE.
 #' @param block_var deprecated
 #' @param clust_var deprecated
+#' @param condition_names deprecated
 #'
 #' @return A list of class "declaration".  The list has five entries:
 #'   $ra_function, a function that generates random assignments according to the declaration.
@@ -48,13 +49,13 @@
 #' declare_ra(N=100, simple = TRUE)
 #' declare_ra(N=100, prob = .4, simple = TRUE)
 #' declare_ra(N=100, prob_each=c(0.3, 0.3, 0.4),
-#'            condition_names=c("control", "placebo", "treatment"), simple=TRUE)
+#'            conditions=c("control", "placebo", "treatment"), simple=TRUE)
 #'
 #' # Complete Random Assignment Declarations
 #'
 #' declare_ra(N=100)
 #' declare_ra(N=100, m_each = c(30, 70),
-#'            condition_names = c("control", "treatment"))
+#'            conditions = c("control", "treatment"))
 #' declare_ra(N=100, m_each=c(30, 30, 40))
 #'
 #'
@@ -103,10 +104,13 @@ declare_ra <- function(N = NULL,
                        block_prob = NULL,
                        block_prob_each = NULL,
                        num_arms = NULL,
-                       condition_names = NULL,
+                       conditions = condition_names,
                        simple = FALSE,
                        permutation_matrix = NULL,
-                       check_inputs = TRUE, block_var=NULL, clust_var=NULL) {
+                       check_inputs = TRUE, 
+                       block_var = NULL, 
+                       clust_var = NULL,
+                       condition_names = NULL) {
   input_check <- NULL
   
   warn_deprecated_args(block_var, clust_var)
@@ -125,7 +129,7 @@ declare_ra <- function(N = NULL,
       block_prob = block_prob,
       block_prob_each = block_prob_each,
       num_arms = num_arms,
-      condition_names = condition_names
+      conditions = conditions
     )
   }
   # Determine ra_type
@@ -164,7 +168,7 @@ declare_ra <- function(N = NULL,
         prob = prob,
         prob_each = prob_each,
         num_arms = num_arms,
-        condition_names = condition_names,
+        conditions = conditions,
         check_inputs = check_inputs
       )
     }
@@ -174,7 +178,7 @@ declare_ra <- function(N = NULL,
         prob = prob,
         prob_each = prob_each,
         num_arms = num_arms,
-        condition_names = condition_names,
+        conditions = conditions,
         check_inputs = check_inputs
       )
   }
@@ -188,7 +192,7 @@ declare_ra <- function(N = NULL,
         prob = prob,
         prob_each = prob_each,
         num_arms = num_arms,
-        condition_names = condition_names,
+        conditions = conditions,
         check_inputs = check_inputs
       )
     }
@@ -201,7 +205,7 @@ declare_ra <- function(N = NULL,
         prob = prob,
         prob_each = prob_each,
         num_arms = num_arms,
-        condition_names = condition_names,
+        conditions = conditions,
         check_inputs = check_inputs
       )
     
@@ -219,7 +223,7 @@ declare_ra <- function(N = NULL,
         prob_each = prob_each,
         block_prob = block_prob,
         block_prob_each = block_prob_each,
-        condition_names = condition_names,
+        conditions = conditions,
         check_inputs = check_inputs
       )
     }
@@ -235,7 +239,7 @@ declare_ra <- function(N = NULL,
         prob_each = prob_each,
         block_prob = block_prob,
         block_prob_each = block_prob_each,
-        condition_names = condition_names,
+        conditions = conditions,
         check_inputs = check_inputs
       )
   }
@@ -250,7 +254,7 @@ declare_ra <- function(N = NULL,
         prob = prob,
         prob_each = prob_each,
         num_arms = num_arms,
-        condition_names = condition_names,
+        conditions = conditions,
         simple = simple,
         check_inputs = check_inputs
       )
@@ -264,7 +268,7 @@ declare_ra <- function(N = NULL,
         prob = prob,
         prob_each = prob_each,
         num_arms = num_arms,
-        condition_names = condition_names,
+        conditions = conditions,
         simple = simple,
         check_inputs = check_inputs
       )
@@ -284,7 +288,7 @@ declare_ra <- function(N = NULL,
         block_m_each = block_m_each,
         block_prob = block_prob,
         block_prob_each = block_prob_each,
-        condition_names = condition_names,
+        conditions = conditions,
         check_inputs = check_inputs
       )
     }
@@ -301,7 +305,7 @@ declare_ra <- function(N = NULL,
         block_m_each = block_m_each,
         block_prob_each = block_prob_each,
         num_arms = num_arms,
-        condition_names = condition_names,
+        conditions = conditions,
         check_inputs = check_inputs
       )
     
@@ -311,13 +315,13 @@ declare_ra <- function(N = NULL,
     ra_function <- function(){
       permutation_matrix[,sample(ncol(permutation_matrix), 1)]
     }
-    condition_names <- sort(unique(c(permutation_matrix)))
+    conditions <- sort(unique(c(permutation_matrix)))
     
     probabilities_matrix <- 
-      sapply(condition_names, 
+      sapply(conditions, 
              FUN = function(x) apply(permutation_matrix, MARGIN = 1, FUN = function(y) mean(y == x)))
     
-    colnames(probabilities_matrix) <- paste0("prob_", condition_names)
+    colnames(probabilities_matrix) <- paste0("prob_", conditions)
     
   }
   
@@ -368,9 +372,12 @@ conduct_ra <- function(declaration = NULL,
                        block_prob = NULL,
                        block_prob_each = NULL,
                        num_arms = NULL,
-                       condition_names = NULL,
+                       conditions = condition_names,
                        simple = FALSE,
-                       check_inputs = TRUE, block_var=NULL, clust_var=NULL) {
+                       check_inputs = TRUE, 
+                       block_var = NULL, 
+                       clust_var = NULL,
+                       condition_names = NULL) {
   if (!is.null(declaration)) {
     if (class(declaration) != "ra_declaration") {
       stop("You must provide a random assignment declaration created by declare_ra().")
@@ -390,7 +397,7 @@ conduct_ra <- function(declaration = NULL,
         block_prob = block_prob,
         block_prob_each = block_prob_each,
         num_arms = num_arms,
-        condition_names = condition_names,
+        conditions = conditions,
         simple = simple,
         check_inputs = check_inputs
       )
@@ -402,7 +409,7 @@ conduct_ra <- function(declaration = NULL,
 #' Obtain the probabilities of units being in the conditions that they are in.
 #'
 #' You can either give obtain_condition_probabilities() an declaration, as created by \code{\link{declare_ra}} or you can specify the other arguments to describe a random assignment procedure.\cr \cr
-#' This function is especially useful when units have different probabilties of assignment and the analyst plans to use inverse-probability weights.
+#' This function is especially useful when units have different probabilities of assignment and the analyst plans to use inverse-probability weights.
 #'
 #'
 #' @param declaration A random assignment declaration, created by \code{\link{declare_ra}}.
@@ -456,8 +463,11 @@ obtain_condition_probabilities <-
            block_prob = NULL,
            block_prob_each = NULL,
            num_arms = NULL,
-           condition_names = NULL,
-           simple = FALSE, block_var=NULL, clust_var=NULL) {
+           conditions = condition_names,
+           simple = FALSE, 
+           block_var = NULL, 
+           clust_var = NULL,
+           condition_names = NULL) {
     # checks
     if (!is.null(declaration)) {
       if (class(declaration) != "ra_declaration") {
@@ -481,7 +491,7 @@ obtain_condition_probabilities <-
           block_prob = block_prob,
           block_prob_each = block_prob_each,
           num_arms = num_arms,
-          condition_names = condition_names,
+          conditions = conditions,
           simple = simple
         )
     }
@@ -505,8 +515,8 @@ print.ra_declaration <- function(x, ...) {
   Z <- x$ra_function()
   n <- length(Z)
   
-  condition_names <- sort(unique(Z))
-  num_arms <- length(condition_names)
+  conditions <- sort(unique(Z))
+  num_arms <- length(conditions)
   constant_probabilities <-
     all(apply(
       x$probabilities_matrix,
@@ -539,7 +549,7 @@ print.ra_declaration <- function(x, ...) {
   cat("Number of treatment arms:", num_arms, "\n")
   cat(
     "The possible treatment categories are ",
-    paste(condition_names, collapse = " and "),
+    paste(conditions, collapse = " and "),
     ".",
     "\n",
     sep = ""
